==> pymongolite-0.1.3.tar.gz: pymongolite-0.1.3/pymongolite/backend/storage_engine/base_engine.py <==
from typing import List, Any
from abc import ABC, abstractmethod

from .read_instructions import ReadInstructions
from .update_instructions import UpdateInstructions
from .insert_instruction import InsertInstructions


class BaseEngine(ABC):
    @abstractmethod
    def create_database(self, database_name: str) -> bool:
        raise NotImplementedError

    @abstractmethod
    def drop_database(self, database_name: str) -> bool:
        raise NotImplementedError

    @abstractmethod
    def create_collection(self, database_name: str, collection_name: str) -> bool:
        raise NotImplementedError

    @abstractmethod
    def drop_collection(self, database_name: str, collection_name: str) -> bool:
        raise NotImplementedError

    @abstractmethod
    def get_collections_list(self, database_name: str) -> List[str]:
        raise NotImplementedError

    @abstractmethod
    def get_documents(
        self,
        database_name: str,
        collection_name: str,
        read_instructions: ReadInstructions,
    ):
        raise NotImplementedError

    @abstractmethod
    def update_documents(
        self,
        database_name: str,
        collection_name: str,
        update_instructions: UpdateInstructions,
    ):
        raise NotImplementedError

    @abstractmethod
    def delete_documents(
        self,
        database_name: str,
        collection_name: str,
        delete_instructions: ReadInstructions,
    ):
        raise NotImplementedError

    @abstractmethod
    def insert_documents(
        self,
        database_name: str,
        collection_name: str,
        insert_instructions: InsertInstructions,
    ) -> List[Any]:
        raise NotImplementedError

==> pymongolite-0.1.6.tar.gz: pymongolite-0.1.6/pymongolite/backend/storage_engine/base_engine.py <==
from typing import List, Any
from abc import ABC, abstractmethod

from pymongolite.backend.read_instructions import ReadInstructions
from pymongolite.backend.storage_engine.update_instructions import UpdateInstructions
from pymongolite.backend.storage_engine.insert_instruction import InsertInstructions


class BaseEngine(ABC):
    @abstractmethod
    def create_database(self, database_name: str) -> bool:
        raise NotImplementedError

    @abstractmethod
    def drop_database(self, database_name: str) -> bool:
        raise NotImplementedError

    @abstractmethod
    def create_collection(self, database_name: str, collection_name: str) -> bool:
        raise NotImplementedError

    @abstractmethod
    def drop_collection(self, database_name: str, collection_name: str) -> bool:
        raise NotImplementedError

    @abstractmethod
    def get_collections_list(self, database_name: str) -> List[str]:
        raise NotImplementedError

    @abstractmethod
    def get_documents(
        self,
        database_name: str,
        collection_name: str,
        read_instructions: ReadInstructions,
    ):
        raise NotImplementedError

    @abstractmethod
    def update_documents(
        self,
        database_name: str,
        collection_name: str,
        update_instructions: UpdateInstructions,
    ) -> List[Any]:
        raise NotImplementedError

    @abstractmethod
    def delete_documents(
        self,
        database_name: str,
        collection_name: str,
        delete_instructions: ReadInstructions,
    ):
        raise NotImplementedError

    @abstractmethod
    def insert_documents(
        self,
        database_name: str,
        collection_name: str,
        insert_instructions: InsertInstructions,
    ) -> List[Any]:
        raise NotImplementedError
